<?php
/**
 * The template for displaying comments
 *
 * This is the template that displays the area of the page that contains both the current comments
 * and the comment form.
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package sleeky
 */

/*
 * If the current post is protected by a password and
 * the visitor has not yet entered the password we will
 * return early without loading the comments.
 */
if ( post_password_required() ) {
	return;
}

	// You can start editing here -- including this comment!
if ( have_comments() ) :
	$comment_close = '';
	if ( ! comments_open() ) :
		$comment_close = 'comment-close';
		endif;
	?>
	<div id="comments-area" class="comment-box <?php echo esc_attr( $comment_close ); ?>">
		<div class="group-title">
			<h2>
				<?php
				$sleeky_comment_count = get_comments_number();
				if ( '1' === $sleeky_comment_count ) {
					printf(
							/* translators: 1: title. */
						esc_html__( 'One Comment', 'sleeky' )
					);
				} else {
					printf(// WPCS: XSS OK.
							/* translators: 1: comment count number, 2: title. */
						esc_html( _nx( '%1$s Comment', '%1$s Comments ', $sleeky_comment_count, 'comments title', 'sleeky' ), 'sleeky' ),
						number_format_i18n( $sleeky_comment_count )
					);
				}
				?>
			</h2>
		</div>
		<?php
		if ( have_comments() ) :
			the_comments_navigation();
			?>
			<div class="blog-comment-list-items">
			<?php
			wp_list_comments(
				array(
					'style'      => 'div',
					'callback'   => 'sleeky_comments',
					'short_ping' => true,
				)
			);
			?>
			</div>
			<?php
				the_comments_navigation();
				// If comments are closed and there are comments, let's leave a little note, shall we?
			if ( ! comments_open() ) :
				?>
					<p class="no-comments"><?php esc_html_e( 'Comments are closed.', 'sleeky' ); ?></p>
					<?php
				endif;
			endif;
		?>
	</div>
	<?php
endif; // Check for have_comments().

if ( comments_open() ) :
	$user                = wp_get_current_user();
	$sleeky_user_identity = $user->display_name;
	$req                 = get_option( 'require_name_email' );
	$aria_req            = $req ? " aria-required='true'" : '';
	$comment_cookies_1   = ' Save my name & email in this browser for next time i comment';

	$formargs = array(
		'class_form'           => 'form-inner',
		'class_container'      => 'comments-form-area',
		'title_reply'          => esc_html__( 'Leave a Comment', 'sleeky' ),
		'title_reply_to'       => esc_html__( 'Leave a Comment to %s', 'sleeky' ),
		'cancel_reply_link'    => esc_html__( 'Cancel Reply', 'sleeky' ),
		'title_reply_before'   => '<div class="group-title"><h2>',
		'title_reply_after'    => '</h2></div>',
		'submit_field'         => '<div class="col-lg-12 col-md-12 col-sm-12 form-group message-btn">%1$s %2$s</div></div>',
		'label_submit'         => esc_html__( 'Submit Comment', 'sleeky' ),
		'comment_notes_before' => '',
		'submit_button'        => '<button type="submit" name="%1$s" id="%2$s" class="%3$s theme-btn btn-one">%4$s</button>',
		'comment_field'        => '<div class="row clearfix"><div class="col-lg-12 col-md-12 col-sm-12 form-group"><textarea id="comment" name="comment" placeholder="' . esc_attr__( 'Write your comment here', 'sleeky' ) . '">' .
		'</textarea></div>',
		'must_log_in'          => '<div>' . sprintf( wp_kses( __( 'You must be <a href="%s">logged in</a> to post a comment.', 'sleeky' ), array( 'a' => array( 'href' => array() ) ) ), wp_login_url( apply_filters( 'the_permalink', get_permalink() ) ) ) . '</div>',
		'logged_in_as'         => '<div class="logged-in-as">' . sprintf( wp_kses( __( 'Logged in as <a href="%1$s">%2$s</a>. <a href="%3$s" title="%4$s">Log out?</a>', 'sleeky' ), array( 'a' => array( 'href' => array() ) ) ), esc_url( admin_url( 'profile.php' ) ), $sleeky_user_identity, wp_logout_url( apply_filters( 'the_permalink', get_permalink() ) ), esc_attr__( 'Log out of this account', 'sleeky' ) ) . '</div>',
		'comment_notes_after'  => '',
		'fields'               => apply_filters(
			'comment_form_default_fields',
			array(
				'author'  =>
				'<div class="col-lg-6 col-md-6 col-sm-12 form-group">'
				. '<input id="author"  name="author" type="text" placeholder="' . esc_attr__( 'Name', 'sleeky' ) . '" value="' . esc_attr( $commenter['comment_author'] ) .
				'" size="30"' . $aria_req . ' /></div>',
				'email'   =>
				'<div class="col-lg-6 col-md-6 col-sm-12 form-group">'
				. '<input id="email" name="email" type="text" placeholder="' . esc_attr__( 'Your Email *', 'sleeky' ) . '" value="' . esc_attr( $commenter['comment_author_email'] ) .
				'" size="30"' . $aria_req . ' /></div>',
				'cookies' => '<div class="col-lg-12 col-md-12 col-sm-12 form-group"><input type="checkbox" required>' . $comment_cookies_1 . '</div>',
			)
		),
	);

	comment_form( $formargs );
endif;
