<?php
/**
 * Build Welcome Page with settings.
 *
 * @package Sleeky
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Build Welcome Page class
 *
 * @category class
 */
class Sleeky_Dashboard_Settings {

	/**
	 * Settings of this class
	 *
	 * @var array
	 */
	public static $settings = array();

	/**
	 * Instance of this class
	 *
	 * @var null
	 */
	private static $instance = null;
	/**
	 * Static var active plugins
	 *
	 * @var $active_plugins
	 */
	private static $active_plugins;

		/**
		 * Holds the verified import files.
		 *
		 * @var array
		 */
	public $import_files;

	/**
	 * Instance Control
	 */
	public static function get_instance() {
		if ( is_null( self::$instance ) ) {
			self::$instance = new self();
		}
		return self::$instance;
	}
	/**
	 * Class Constructor.
	 */
	public function __construct() {
		// only load if admin.
		if ( is_admin() ) {
			add_action( 'admin_menu', array( $this, 'add_menu' ) );
		}
		add_action( 'init', array( $this, 'load_api_settings' ) );

	}
	/**
	 * Redirect to the settings page on activation.
	 *
	 * @param string $key setting key.
	 */
	public static function get_data_options( $key ) {
		if ( ! isset( self::$settings[ $key ] ) ) {
			self::$settings[ $key ] = get_option( $key, array() );
		}
		return self::$settings[ $key ];
	}
	/**
	 * Add option page menu
	 */
	public function add_menu() {
		$page = add_theme_page( __( 'Sleeky - Next Generation Theme', 'sleeky' ), __( 'Sleeky', 'sleeky' ), apply_filters( 'sleeky_admin_settings_capability', 'manage_options' ), 'sleeky', array( $this, 'config_page' ), 4 );
		add_action( 'admin_print_styles-' . $page, array( $this, 'scripts' ) );
	}
	/**
	 * Initialize getting the active plugins list.
	 */
	public static function get_active_plugins() {

		self::$active_plugins = (array) get_option( 'active_plugins', array() );

		if ( is_multisite() ) {
			self::$active_plugins = array_merge( self::$active_plugins, get_site_option( 'active_sitewide_plugins', array() ) );
		}
	}
	/**
	 * Active Plugin Check
	 *
	 * @param string $plugin_base_name is plugin folder/filename.php.
	 */
	public static function active_plugin_check( $plugin_base_name ) {

		if ( ! self::$active_plugins ) {
			self::get_active_plugins();
		}
		return in_array( $plugin_base_name, self::$active_plugins, true ) || array_key_exists( $plugin_base_name, self::$active_plugins );
	}
	/**
	 * Loads admin style sheets and scripts
	 */
	public function scripts() {
		$installed_plugins = get_plugins();
		$button_label      = esc_html__( 'Browse Sleeky Demo Import', 'sleeky' );
		$data_action       = '';

		wp_enqueue_style( 'sleeky-dashboard', get_template_directory_uri() . '/inc/dashboard/css/dash-controls.min.css', array( 'wp-components' ), time() );
		wp_enqueue_script( 'sleeky-dashboard', get_template_directory_uri() . '/inc/dashboard/js/dash-controls.js', array( 'jquery' ), time(), true );
		wp_localize_script(
			'sleeky-dashboard',
			'sleekyDashboardParams',
			array(
				'adminURL'         => esc_url( admin_url() ),
				'settings'         => esc_attr( get_option( 'sleeky_theme_config' ) ),
				'changelog'        => $this->get_changelog(),
				'proChangelog'     => ( class_exists( 'Sleeky_Theme_Pro' ) ? $this->get_pro_changelog() : '' ),
				'starterTemplates' => ( defined( 'SLEEKY_STARTER_TEMPLATES_VERSION' ) ? true : false ),
				'ajax_url'         => admin_url( 'admin-ajax.php' ),
				'ajax_nonce'       => wp_create_nonce( 'sleeky-ajax-verification' ),
				'status'           => $data_action,
				'starterLabel'     => $button_label,
				'starterImage'     => esc_attr( get_template_directory_uri() . '/assets/images/starter-templates-banner.jpeg' ),
				'starterURL'       => esc_url( admin_url( 'themes.php?page=sleeky-starter-templates' ) ),
				'videoImage'       => esc_attr( get_template_directory_uri() . '/assets/images/getting-started-video.jpg' ),
			)
		);
		if ( function_exists( 'wp_set_script_translations' ) ) {
			wp_set_script_translations( 'sleeky-dashboard', 'sleeky' );
		}
	}
	/**
	 * Get Changelog ( Largely Borrowed From Neve Theme )
	 */
	public function get_changelog() {
		$changelog      = array();
		$changelog_path = get_template_directory() . '/changelog.txt';
		if ( ! is_file( $changelog_path ) ) {
			return $changelog;
		}
		global $wp_filesystem;
		if ( ! is_object( $wp_filesystem ) ) {
			require_once ABSPATH . '/wp-admin/includes/file.php';
			WP_Filesystem();
		}

		$changelog_string = $wp_filesystem->get_contents( $changelog_path );
		if ( is_wp_error( $changelog_string ) ) {
			return $changelog;
		}
		$changelog = explode( PHP_EOL, $changelog_string );
		$releases  = array();
		foreach ( $changelog as $changelog_line ) {
			if ( empty( $changelog_line ) ) {
				continue;
			}
			if ( substr( ltrim( $changelog_line ), 0, 2 ) === '==' ) {
				if ( isset( $release ) ) {
					$releases[] = $release;
				}
				$changelog_line = trim( str_replace( '=', '', $changelog_line ) );
				$release        = array(
					'head' => $changelog_line,
				);
			} else {
				if ( preg_match( '/[*|-]?\s?(\[fix]|\[Fix]|fix|Fix)[:]?\s?\b/', $changelog_line ) ) {
					// $changelog_line     = preg_replace( '/[*|-]?\s?(\[fix]|\[Fix]|fix|Fix)[:]?\s?\b/', '', $changelog_line );
					$changelog_line   = trim( str_replace( array( '*', '-' ), '', $changelog_line ) );
					$release['fix'][] = $changelog_line;
					continue;
				}

				if ( preg_match( '/[*|-]?\s?(\[add]|\[Add]|add|Add)[:]?\s?\b/', $changelog_line ) ) {
					// $changelog_line        = preg_replace( '/[*|-]?\s?(\[add]|\[Add]|add|Add)[:]?\s?\b/', '', $changelog_line );
					$changelog_line   = trim( str_replace( array( '*', '-' ), '', $changelog_line ) );
					$release['add'][] = $changelog_line;
					continue;
				}
				$changelog_line      = trim( str_replace( array( '*', '-' ), '', $changelog_line ) );
				$release['update'][] = $changelog_line;
			}
		}
		return $releases;
	}
	/**
	 * Get Changelog ( Largely Borrowed From Neve Theme )
	 */
	public function get_pro_changelog() {
		$changelog = array();
		if ( ! defined( 'KTP_PATH' ) ) {
			return $changelog;
		}
		$changelog_path = KTP_PATH . '/changelog.txt';
		if ( ! is_file( $changelog_path ) ) {
			return $changelog;
		}
		global $wp_filesystem;
		if ( ! is_object( $wp_filesystem ) ) {
			require_once ABSPATH . '/wp-admin/includes/file.php';
			WP_Filesystem();
		}

		$changelog_string = $wp_filesystem->get_contents( $changelog_path );
		if ( is_wp_error( $changelog_string ) ) {
			return $changelog;
		}
		$changelog = explode( PHP_EOL, $changelog_string );
		$releases  = array();
		foreach ( $changelog as $changelog_line ) {
			if ( empty( $changelog_line ) ) {
				continue;
			}
			if ( substr( ltrim( $changelog_line ), 0, 2 ) === '==' ) {
				if ( isset( $release ) ) {
					$releases[] = $release;
				}
				$changelog_line = trim( str_replace( '=', '', $changelog_line ) );
				$release        = array(
					'head' => $changelog_line,
				);
			} else {
				if ( preg_match( '/[*|-]?\s?(\[fix]|\[Fix]|fix|Fix)[:]?\s?\b/', $changelog_line ) ) {
					// $changelog_line     = preg_replace( '/[*|-]?\s?(\[fix]|\[Fix]|fix|Fix)[:]?\s?\b/', '', $changelog_line );
					$changelog_line   = trim( str_replace( array( '*', '-' ), '', $changelog_line ) );
					$release['fix'][] = $changelog_line;
					continue;
				}

				if ( preg_match( '/[*|-]?\s?(\[add]|\[Add]|add|Add)[:]?\s?\b/', $changelog_line ) ) {
					$changelog_line   = trim( str_replace( array( '*', '-' ), '', $changelog_line ) );
					$release['add'][] = $changelog_line;
					continue;
				}
				$changelog_line      = trim( str_replace( array( '*', '-' ), '', $changelog_line ) );
				$release['update'][] = $changelog_line;
			}
		}
		return $releases;
	}

	/**
	 * Register settings
	 */
	public function load_api_settings() {

		register_setting(
			'sleeky_theme_config',
			'sleeky_theme_config',
			array(
				'type'              => 'string',
				'description'       => __( 'Config Sleeky Modules', 'sleeky' ),
				'sanitize_callback' => 'sanitize_text_field',
				'show_in_rest'      => true,
				'default'           => '',
			)
		);
	}

	/**
	 * Loads config page
	 */
	public function config_page() {
		?>
		<div class="wrap sleeky_theme_dash">
			<div class="sleeky_theme_dashboard">
				<?php settings_errors(); ?>
				<div class="page-grid">
					<div class="sleeky_theme_dashboard_main">
						<div class="tab-panel">
							<div class="sleeky-dashboard-tab-panel">
								<div role="tablist" aria-orientation="horizontal" class="components-tab-panel__tabs">
									<button type="button" role="tab" aria-selected="true" data-tab="#tab-panel-1" class="components-button components-tab-panel__tabs-item sleeky-dash-tab active-tab-nav"><?php esc_html_e( 'Dashboard', 'sleeky' ); ?></button>
									<button type="button" role="tab" aria-selected="false" data-tab="#tab-panel-2" class="components-button components-tab-panel__tabs-item sleeky-help-tab" tabindex="-1"><?php esc_html_e( 'Getting Started', 'sleeky' ); ?></button>
									<button type="button" role="tab" aria-selected="false" data-tab="#tab-panel-3" class="components-button components-tab-panel__tabs-item sleeky-changelog-tab" tabindex="-1">
									<?php esc_html_e( 'Changelog', 'sleeky' ); ?>
									</button>
									<?php if ( class_exists( 'OCDI_Plugin' ) ) { ?>
									<a href="<?php echo 'themes.php?page=demo-content-install'; ?>" class="components-button">
										<?php esc_html_e( 'Demo Import', 'sleeky' ); ?>
									</a>
									<?php } ?>
								</div>
								<div aria-labelledby="tab-panel-0-dashboard" role="tabpanel" id="tab-panel-0-dashboard-view" class="components-tab-panel__tab-content">
									<div class="dashboard-section tab-section components-panel active-tab" id="tab-panel-1">
										<div class="components-panel__body is-opened">
											<div class="dashboard-modules-wrapper">
												<div class="dashboard-customizer-settings">
													<h2 class="section-header">Customize Your Site</h2>
													<div class="two-col-grid">
														<div class="link-item">
															<h4>Branding</h4>
															<p>Upload your logo and favicon.</p>
															<div class="link-item-foot"><a href="http://localhost/wp-themes/sleeky/wp-admin/customize.php?autofocus%5Bsection%5D=title_tagline">Customize</a></div>
														</div>
														<div class="link-item">
															<h4>Global Colors</h4>
															<p>Setup the base color scheme for your site.</p>
															<div class="link-item-foot"><a href="http://localhost/wp-themes/sleeky/wp-admin/customize.php?return=%2Fwp-themes%2Fsleeky%2Fwp-admin%2Fthemes.php%3Fpage%3Dsleeky">Customize</a></div>
														</div>
														<div class="link-item">
															<h4>Global Typography</h4>
															<p>Choose the perfect font family, style and sizes.</p>
															<div class="link-item-foot"><a href="http://localhost/wp-themes/sleeky/wp-admin/customize.php?autofocus%5Bsection%5D=sleeky_customizer_general_typography">Customize</a></div>
														</div>
														<div class="link-item">
															<h4>Header Layout</h4>
															<p>Add elements and arrange them how you want.</p>
															<div class="link-item-foot"><a href="http://localhost/wp-themes/sleeky/wp-admin/customize.php?autofocus%5Bpanel%5D=sleeky_customizer_header">Customize</a></div>
														</div>
														<div class="link-item">
															<h4>Footer Layout</h4>
															<p>Customize the columns and place widget areas in unlimited configurations</p>
															<div class="link-item-foot"><a href="http://localhost/wp-themes/sleeky/wp-admin/customize.php?autofocus%5Bsection%5D=sleeky_customizer_footer_layout">Customize</a></div>
														</div>
													</div>
												</div>
												<div class="dashboard-pro-settings">
													<h2 class="section-header"><?php esc_html_e( 'Do more with the Sleeky Pro Classy Extension', 'sleeky' ); ?></h2>
													<div class="two-col-grid">
														<div class="link-item locked-item">
															<span class="lock-icon">
																<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 50 50">
																	<path d="M34 23h-2v-4c0-3.9-3.1-7-7-7s-7 3.1-7 7v4h-2v-4c0-5 4-9 9-9s9 4 9 9v4z"></path>
																	<path d="M33 40H17c-1.7 0-3-1.3-3-3V25c0-1.7 1.3-3 3-3h16c1.7 0 3 1.3 3 3v12c0 1.7-1.3 3-3 3zM17 24c-.6 0-1 .4-1 1v12c0 .6.4 1 1 1h16c.6 0 1-.4 1-1V25c0-.6-.4-1-1-1H17z"></path>
																	<circle cx="25" cy="28" r="2"></circle>
																	<path d="M25.5 28h-1l-1 6h3z"></path>
																</svg>
															</span>
															<h4><?php esc_html_e( 'Elementor Addons', 'sleeky' ); ?></h4>
															<p><?php esc_html_e( '30+ Elementor Ready Widgets', 'sleeky' ); ?></p>
															<div class="link-item-foot"><a href="https://themesmaster.com/sleeky-details/" target="_blank">Learn More</a></div>
														</div>
														<div class="link-item locked-item">
															<span class="lock-icon">
																<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 50 50">
																	<path d="M34 23h-2v-4c0-3.9-3.1-7-7-7s-7 3.1-7 7v4h-2v-4c0-5 4-9 9-9s9 4 9 9v4z"></path>
																	<path d="M33 40H17c-1.7 0-3-1.3-3-3V25c0-1.7 1.3-3 3-3h16c1.7 0 3 1.3 3 3v12c0 1.7-1.3 3-3 3zM17 24c-.6 0-1 .4-1 1v12c0 .6.4 1 1 1h16c.6 0 1-.4 1-1V25c0-.6-.4-1-1-1H17z"></path>
																	<circle cx="25" cy="28" r="2"></circle>
																	<path d="M25.5 28h-1l-1 6h3z"></path>
																</svg>
															</span>
															<h4><?php esc_html_e( 'Home Pages', 'sleeky' ); ?></h4>
															<p><?php esc_html_e( 'Four Home Pages Ready', 'sleeky' ); ?></p>
															<div class="link-item-foot"><a href="https://themesmaster.com/sleeky-details/" target="_blank">Learn More</a></div>
														</div>
														<div class="link-item locked-item">
															<span class="lock-icon">
																<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 50 50">
																	<path d="M34 23h-2v-4c0-3.9-3.1-7-7-7s-7 3.1-7 7v4h-2v-4c0-5 4-9 9-9s9 4 9 9v4z"></path>
																	<path d="M33 40H17c-1.7 0-3-1.3-3-3V25c0-1.7 1.3-3 3-3h16c1.7 0 3 1.3 3 3v12c0 1.7-1.3 3-3 3zM17 24c-.6 0-1 .4-1 1v12c0 .6.4 1 1 1h16c.6 0 1-.4 1-1V25c0-.6-.4-1-1-1H17z"></path>
																	<circle cx="25" cy="28" r="2"></circle>
																	<path d="M25.5 28h-1l-1 6h3z"></path>
																</svg>
															</span>
															<h4><?php esc_html_e( 'Advance Filter', 'sleeky' ); ?></h4>
															<p><?php esc_html_e( 'Advance Shop Page Filter', 'sleeky' ); ?></p>
															<div class="link-item-foot"><a href="https://themesmaster.com/sleeky-details/" target="_blank">Learn More</a></div>
														</div>
														<div class="link-item locked-item">
															<span class="lock-icon">
																<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 50 50">
																	<path d="M34 23h-2v-4c0-3.9-3.1-7-7-7s-7 3.1-7 7v4h-2v-4c0-5 4-9 9-9s9 4 9 9v4z"></path>
																	<path d="M33 40H17c-1.7 0-3-1.3-3-3V25c0-1.7 1.3-3 3-3h16c1.7 0 3 1.3 3 3v12c0 1.7-1.3 3-3 3zM17 24c-.6 0-1 .4-1 1v12c0 .6.4 1 1 1h16c.6 0 1-.4 1-1V25c0-.6-.4-1-1-1H17z"></path>
																	<circle cx="25" cy="28" r="2"></circle>
																	<path d="M25.5 28h-1l-1 6h3z"></path>
																</svg>
															</span>
															<h4><?php esc_html_e( 'Header Option', 'sleeky' ); ?></h4>
															<p><?php esc_html_e( 'Individual Page Header Option.', 'sleeky' ); ?></p>
															<div class="link-item-foot"><a href="https://themesmaster.com/sleeky-details/" target="_blank">Learn More</a></div>
														</div>
														<div class="link-item locked-item">
															<span class="lock-icon">
																<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 50 50">
																	<path d="M34 23h-2v-4c0-3.9-3.1-7-7-7s-7 3.1-7 7v4h-2v-4c0-5 4-9 9-9s9 4 9 9v4z"></path>
																	<path d="M33 40H17c-1.7 0-3-1.3-3-3V25c0-1.7 1.3-3 3-3h16c1.7 0 3 1.3 3 3v12c0 1.7-1.3 3-3 3zM17 24c-.6 0-1 .4-1 1v12c0 .6.4 1 1 1h16c.6 0 1-.4 1-1V25c0-.6-.4-1-1-1H17z"></path>
																	<circle cx="25" cy="28" r="2"></circle>
																	<path d="M25.5 28h-1l-1 6h3z"></path>
																</svg>
															</span>
															<h4><?php esc_html_e( 'Footer Option', 'sleeky' ); ?></h4>
															<p><?php esc_html_e( 'Individual Page Footer Option', 'sleeky' ); ?></p>
															<div class="link-item-foot"><a href="https://themesmaster.com/sleeky-details/" target="_blank"><?php esc_html_e( 'Learn More', 'sleeky' ); ?></a></div>
														</div>
														<div class="link-item locked-item">
															<span class="lock-icon">
																<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 50 50">
																	<path d="M34 23h-2v-4c0-3.9-3.1-7-7-7s-7 3.1-7 7v4h-2v-4c0-5 4-9 9-9s9 4 9 9v4z"></path>
																	<path d="M33 40H17c-1.7 0-3-1.3-3-3V25c0-1.7 1.3-3 3-3h16c1.7 0 3 1.3 3 3v12c0 1.7-1.3 3-3 3zM17 24c-.6 0-1 .4-1 1v12c0 .6.4 1 1 1h16c.6 0 1-.4 1-1V25c0-.6-.4-1-1-1H17z"></path>
																	<circle cx="25" cy="28" r="2"></circle>
																	<path d="M25.5 28h-1l-1 6h3z"></path>
																</svg>
															</span>
															<h4><?php esc_html_e( 'Custom Icons Support', 'sleeky' ); ?></h4>
															<p><?php esc_html_e( 'Custom Icons Support', 'sleeky' ); ?></p>
															<div class="link-item-foot"><a href="https://themesmaster.com/sleeky-details/" target="_blank"><?php esc_html_e( 'Learn More', 'sleeky' ); ?></a></div>
														</div>
													</div>
												</div>
											</div>
										</div>
									</div>
									<div class="help-section tab-section components-panel" id="tab-panel-2">
										<div class="components-panel__body is-opened">
											<div class="sleeky-desk-help-inner">
												<h2><?php esc_html_e( 'Welcome to Sleeky!', 'sleeky' ); ?></h2>
												<p><?php esc_html_e( 'You are going to love working with this theme! View the video below to get started with our video tutorials or click the view knowledge base button below to see all the documentation.', 'sleeky' ); ?></p>
												<div class="video-container"><a href="https://www.youtube.com/c/SmartDataSoft"><img src="<?php echo SLEEKY_THEME_URI; ?>/inc/dashboard/images/getting-started-video.png" width="1280" height="720"></a>
												</div>
												<a href="https://www.youtube.com/c/SmartDataSoft" class="sleeky-desk-button" target="_blank"><?php esc_html_e( 'Video Tutorials', 'sleeky' ); ?></a><a href="https://smartdatasoft.com/docs/sleeky/" class="sleeky-desk-button sleeky-desk-button-second" target="_blank"><?php esc_html_e( 'View Knowledge Base', 'sleeky' ); ?></a>
											</div>
										</div>
									</div>
									<div class="changelog-section tab-section components-panel" id="tab-panel-3">
										<div class="components-panel__body is-opened">
											<div class="changelog-version">
												<h3 class="version-head">1.0.0 | 18 July 2022</h3>
												<div class="version-add">Initial Release</div>
											</div>
										</div>
									</div>
								</div>
							</div>
						</div>
					</div>
					<div class="side-panel">
						<?php do_action( 'sleeky_theme_dash_side_panel' ); ?>
						<div class="community-section sidebar-section components-panel">
							<div class="components-panel__body is-opened">
								<h2><?php esc_html_e( 'Web Creators Community', 'sleeky' ); ?></h2>
								<p><?php esc_html_e( 'Join our community of fellow sleeky users creating effective websites! Share your site, ask a question and help others.', 'sleeky' ); ?></p>
								<a href="https://www.facebook.com/groups/smartdatasoft" target="_blank" class="sidebar-link"><?php esc_html_e( 'Join our Facebook Group', 'sleeky' ); ?></a>
							</div>
						</div>
						<div class="support-section sidebar-section components-panel">
							<div class="components-panel__body is-opened">
								<h2><?php esc_html_e( 'Video Tutorials', 'sleeky' ); ?></h2>
								<p><?php esc_html_e( 'Want a guide? We have video tutorials to walk you through getting started.', 'sleeky' ); ?></p>
								<a href="https://www.youtube.com/c/SmartDataSoft" target="_blank" class="sidebar-link"><?php esc_html_e( 'Watch Videos', 'sleeky' ); ?></a>
							</div>
						</div>
						<div class="support-section sidebar-section components-panel">
							<div class="components-panel__body is-opened">
								<h2><?php esc_html_e( 'Documentation', 'sleeky' ); ?></h2>
								<p><?php esc_html_e( 'Need help? We have a knowledge base full of articles to get you started.', 'sleeky' ); ?></p>
								<a href="https://smartdatasoft.com/docs/sleeky/" target="_blank" class="sidebar-link"><?php esc_html_e( 'Browse Docs', 'sleeky' ); ?></a>
							</div>
						</div>
						<div class="support-section sidebar-section components-panel">
							<div class="components-panel__body is-opened">
								<h2><?php esc_html_e( 'Support', 'sleeky' ); ?></h2>
								<p><?php esc_html_e( 'Have a question, we are happy to help! Get in touch with our support team.', 'sleeky' ); ?></p>
								<a href="https://support.smartdatasoft.com/" target="_blank" class="sidebar-link"><?php esc_html_e( 'Submit a Ticket', 'sleeky' ); ?></a>
							</div>
						</div>
					</div>
				</div>
			</div>
		</div>
		<?php
	}

}
Sleeky_Dashboard_Settings::get_instance();
